<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'init', 'custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
  
  /* OptionTree is not loaded yet, or this is not an admin request */
  if ( ! function_exists( 'ot_settings_id' ) || ! is_admin() )
    return false;
    
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( ot_settings_id(), array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'general',
        'title'       => 'General'
      ),
      array(
        'id'          => 'home_settings',
        'title'       => 'Home Layout settings'
      ),
      array(
        'id'          => 'home_slider_settings',
        'title'       => 'Home Slider Settings'
      ),
      array(
        'id'          => 'social_media_settings',
        'title'       => 'Social Media Settings'
      )
    ),
    'settings'        => array( 
      array(
        'id'          => 'logo',
        'label'       => 'Logo',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
array(
        'id'          => 'footer_developer_link',
        'label'       => __( 'footer developer link', 'glassy_shop' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'general',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),

      array(
        'id'          => 'email_address',
        'label'       => 'Email Address',
        'desc'        => 'It\'s displayed in the top left header',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'home_sidebar_ad_code',
        'label'       => 'Home sidebar ad code',
        'desc'        => '',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'tab1_category',
        'label'       => 'Tab1 category slug',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => 'product',
        'taxonomy'    => 'product_cat',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'tab2__category',
        'label'       => 'Tab2  category slug',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'featured_box1',
        'label'       => 'Featured box1',
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'featured_image1',
        'label'       => 'Featured Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'box_title1',
        'label'       => 'Box Title',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'link_url1',
        'label'       => 'Link url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'featured_box2',
        'label'       => 'Featured box2',
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'featured_image2',
        'label'       => 'Featured image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'box_title2',
        'label'       => 'Box Title',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'link_url2',
        'label'       => 'Link url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'featured_box3',
        'label'       => 'Featured Box3',
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'featured__image3',
        'label'       => 'Featured  image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'box_title3',
        'label'       => 'Box Title',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'link_url3',
        'label'       => 'Link url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider1',
        'label'       => 'Slider1',
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_image',
        'label'       => 'Slider Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_head_line',
        'label'       => 'Slider Headline',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_text',
        'label'       => 'Slider Text',
        'desc'        => '',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_link_url',
        'label'       => 'Slider Link url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider2',
        'label'       => 'Slider2',
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_image2',
        'label'       => 'Slider Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_head_line2',
        'label'       => 'Slider Headline',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_text2',
        'label'       => 'Slider Text',
        'desc'        => '',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_link_url2',
        'label'       => 'Slider Link url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider3',
        'label'       => 'Slider3',
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_image3',
        'label'       => 'Slider  Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_headline3',
        'label'       => 'Slider Headline',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_text3',
        'label'       => 'Slider Text',
        'desc'        => '',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_link_url3',
        'label'       => 'Slider Link url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider4',
        'label'       => 'Slider4',
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_image4',
        'label'       => 'Slider Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_headline4',
        'label'       => 'Slider Headline',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_text4',
        'label'       => 'Slider Text',
        'desc'        => '',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_link_url4',
        'label'       => 'Slider Link url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider5',
        'label'       => 'Slider5',
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_image5',
        'label'       => 'Slider Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_headline5',
        'label'       => 'Slider Headline',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_text5',
        'label'       => 'Slider Text',
        'desc'        => '',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'slider_link_url5',
        'label'       => 'Slider Link Url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_slider_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'facebook_url',
        'label'       => 'Facebook url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'twitter_url',
        'label'       => 'Twitter url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'google_plus_url',
        'label'       => 'Google plus Url',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_media_settings',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      )
    )
  );
  
   
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( ot_settings_id() . '_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( ot_settings_id(), $custom_settings ); 
  }
  
  /* Lets OptionTree know the UI Builder is being overridden */
  global $ot_has_custom_theme_options;
  $ot_has_custom_theme_options = true;
  if(function_exists("register_field_group"))
{
	register_field_group(array (
		'id' => 'acf_featured-product-settings',
		'title' => 'Featured Product Settings',
		'fields' => array (
			array (
				'key' => 'field_552d13efa96bb',
				'label' => 'Make this product as Featured?',
				'name' => 'make_this_product_as_featured',
				'type' => 'select',
				'choices' => array (
					'Yes' => 'Yes',
					'No' => 'No',
				),
				'default_value' => '',
				'allow_null' => 1,
				'multiple' => 0,
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'product',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'side',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
	register_field_group(array (
		'id' => 'acf_slider-settings',
		'title' => 'Slider Settings',
		'fields' => array (
			array (
				'key' => 'field_555c28c61ef03',
				'label' => 'Home slider',
				'name' => 'home_slider',
				'type' => 'repeater',
				'sub_fields' => array (
					array (
						'key' => 'field_555c29091ef04',
						'label' => 'Slider image',
						'name' => 'slider_image',
						'type' => 'image',
						'column_width' => '',
						'save_format' => 'object',
						'preview_size' => 'thumbnail',
						'library' => 'all',
					),
					array (
						'key' => 'field_555c294a1ef05',
						'label' => 'Slider Head Line',
						'name' => 'slider_head_line',
						'type' => 'text',
						'column_width' => '',
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'formatting' => 'html',
						'maxlength' => '',
					),
					array (
						'key' => 'field_555c295b1ef06',
						'label' => 'Slider Text',
						'name' => 'slider_text',
						'type' => 'textarea',
						'column_width' => '',
						'default_value' => '',
						'placeholder' => '',
						'maxlength' => '',
						'rows' => '',
						'formatting' => 'br',
					),
					array (
						'key' => 'field_555c29bc1ef07',
						'label' => 'Link Button url',
						'name' => 'link_button_url',
						'type' => 'text',
						'column_width' => '',
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'formatting' => 'html',
						'maxlength' => '',
					),
				),
				'row_min' => 0,
				'row_limit' => '',
				'layout' => 'row',
				'button_label' => 'Add Slider',
			),
		),
		'location' => array (
			array (
				array (
					'param' => 'page_template',
					'operator' => '==',
					'value' => 'home.php',
					'order_no' => 0,
					'group_no' => 0,
				),
			),
		),
		'options' => array (
			'position' => 'normal',
			'layout' => 'default',
			'hide_on_screen' => array (
			),
		),
		'menu_order' => 0,
	));
}

}